.. _pynetworktables_examples:

Examples
========

These are the simple examples that are included with pynetworktables.

Robot Example
-------------

.. literalinclude:: ../samples/nt_robot.py

Driver Station Example
----------------------

.. literalinclude:: ../samples/nt_driverstation.py

Listener Example
----------------

.. literalinclude:: ../samples/listener.py

Listen Chooser Example
----------------------

.. literalinclude:: ../samples/listen_chooser.py

Auto Listener Example
---------------------

.. literalinclude:: ../samples/auto_listener.py

Global Listener Example
-----------------------

.. literalinclude:: ../samples/global_listener.py

ntproperty Example
------------------

.. literalinclude:: ../samples/ntproperty_client.py

json_logger Example
-------------------

This is a more complex example which can be used to log data from your robot
into a JSON file. There is a corresponding

As this example is a bit larger than the others, see the 'samples/json_logger'
directory of the pynetworktables repository on github. It also includes a script
that you can modify to plot the data.
